@@ -106,7 +106,9 @@ class RPCClient(object):
     def call_async(self, channel, type, request):
         return self._call(channel, type, request)
 
-    def call_sync(self, channel, type, request):
+    def call_sync(self, channel, type, request, timeout=None):
+        if timeout is None:
+            timeout = self.sync_timeout
         self.log.debug("running in sync mode, this may cause delay")
         rpc_id = self.call_async(channel, type, request)
         if channel not in self.channels:
@@ -127,12 +129,12 @@ class RPCClient(object):
                     self.results.pop(rpc_id, None)
                 return self.return_success(entry.result)
             duration = (time.time() - entry.timestamp)
-            if duration > self.sync_timeout:
+            if duration > timeout:
                 return self.return_error("timeout")
-            time.sleep(self.sync_timeout / 5.0)
+            time.sleep(timeout / 5.0)
 
-    def rpc(self, channel, type, request):
-        result = self.call_sync(channel, type, request)
+    def rpc(self, channel, type, request, timeout=None):
+        result = self.call_sync(channel, type, request, timeout=timeout)
         return result.get("response") or {}
 
     def recv_thread(self):
